macro_rules! arc_mutex {
($e:expr) => { ... };
}Expand description
Wraps an expression in an Arc<tokio::sync::Mutex<T>>.
The go-to pattern for shared mutable state in async Axum/Tokio apps.
macro_rules! arc_mutex {
($e:expr) => { ... };
}Wraps an expression in an Arc<tokio::sync::Mutex<T>>.
The go-to pattern for shared mutable state in async Axum/Tokio apps.